@@ -3,13 +3,12 @@ from logging import getLogger
 
 import luigi
 
-import gokart
 from gokart.task import TaskOnKart
 
 logger = getLogger(__name__)
 
 
-def make_tree_info(task, indent='', last=True, details=False):
+def make_tree_info(task, indent='', last=True, details=False, abbr=True, visited_tasks=None):
     """
     Return a string representation of the tasks, their statuses/parameters in a dependency tree format
     """
@@ -26,6 +25,16 @@ def make_tree_info(task, indent='', last=True, details=False):
         indent += '|  '
     name = task.__class__.__name__
     result += f'({is_complete}) {name}[{task.make_unique_id()}]'
+
+    if abbr:
+        visited_tasks = visited_tasks or set()
+        task_id = f'{name}_{task.make_unique_id()}'
+        if task_id not in visited_tasks:
+            visited_tasks.add(task_id)
+        else:
+            result += f'\n{indent}└─- ...'
+            return result
+
     if details:
         params = task.get_info(only_significant=True)
         output_paths = [t.path() for t in luigi.task.flatten(task.output())]
@@ -33,9 +42,10 @@ def make_tree_info(task, indent='', last=True, details=False):
         if type(processing_time) == float:
             processing_time = str(processing_time) + 's'
         result += f'(parameter={params}, output={output_paths}, time={processing_time}, task_log={dict(task.get_task_log())})'
+
     children = luigi.task.flatten(task.requires())
     for index, child in enumerate(children):
-        result += make_tree_info(child, indent, (index + 1) == len(children), details=details)
+        result += make_tree_info(child, indent, (index + 1) == len(children), details=details, abbr=abbr, visited_tasks=visited_tasks)
     return result
 
 
