@@ -1,5 +1,5 @@
-from gokart.zip_client import ZipClient, LocalZipClient
 from gokart.object_storage import ObjectStorage
+from gokart.zip_client import LocalZipClient, ZipClient
 
 
 def make_zip_client(file_path: str, temporary_directory: str) -> ZipClient:
